@@ -1,15 +1,16 @@
 from os import read
 from typing import Any, Dict
 from datapatch.lookup import Lookup
+from datapatch.result import Result
 from datapatch.util import read_yaml_file, PathLike
 from datapatch.exc import LookupException
 
 
-__version__ = "0.2.0"
-__all__ = ["Lookup", "LookupException", "get_lookups", "read_lookups"]
+__version__ = "1.0.0"
+__all__ = ["Lookup", "Result", "LookupException", "get_lookups", "read_lookups"]
 
 
-def get_lookups(data: Any) -> Dict[str, Lookup]:
+def get_lookups(data: Dict[str, Dict[str, Any]]) -> Dict[str, Lookup]:
     """Turn a mapping of configs into a dict of Lookups."""
     lookups = {}
     for name, config in data.items():
